@@ -163,7 +163,7 @@ static int decode_frame(AVCodecContext *avctx,
         if(i) {
             AVRational q = av_d2q(av_int2float(i), 4096);
             if (q.num > 0 && q.den > 0)
-                avctx->time_base = av_inv_q(q);
+                avctx->framerate = q;
         }
     }
 
@@ -334,11 +334,11 @@ static int decode_frame(AVCodecContext *avctx,
                 // For 12 bit, ignore alpha
                 if (elements == 4)
                     buf += 2;
+                // Jump to next aligned position
+                buf += need_align;
             }
             for (i = 0; i < 3; i++)
                 ptr[i] += p->linesize[i];
-            // Jump to next aligned position
-            buf += need_align;
         }
         break;
     case 16:
